@@ -203,7 +203,8 @@ def ResourceLevelEnum(ctx):
         medium=2,
         high=3,
         unknown1=4,
-        unknown2=5
+        unknown2=5,
+        unknown3=6
     )
 
 def RevealMapEnum(ctx):
@@ -222,7 +223,7 @@ def AgeEnum(ctx):
         ctx,
         what=-2,
         unset=-1,
-        standard=0,
+        dark=0,
         feudal=1,
         castle=2,
         imperial=3,
