@@ -98,14 +98,17 @@ def _validate(data, players):
     numbers = [p['number'] for p in players]
     if 'player_number' in data and data['player_number'] not in numbers:
         return False
-    if data['timestamp'] > 0 and data['timestamp'] < 1000:
-        return False
     return True
 
 
 def _parse_json(data, line, diplomacy_type):
     """Parse DE JSON chat."""
     payload = json.loads(line)
+    if payload['messageAGP'] == '':
+        # Use this condition to tell whether to ignore the chat. It might be from another game for example.
+        data['type'] = Chat.DISCARD
+        return
+
     audience = 'team'
     if payload['channel'] == 0:
         if diplomacy_type == '1v1':
